@@ -50,7 +50,7 @@ BEGIN{
         },
     );
 
-    our $VERSION = '2.4.1';
+    our $VERSION = '2.4.2';
 
     my $xs = !(defined(&is_valid_class_name) || $ENV{MOUSE_PUREPERL} || $ENV{PERL_ONLY});
 
@@ -76,7 +76,10 @@ BEGIN{
         require 'Mouse/PurePerl.pm'; # we don't want to create its namespace
     }
 
-    *MOUSE_XS = sub(){ $xs };
+    {
+        my $value = $xs; # avoid "Constants from lexical variables potentially modified elsewhere are deprecated"
+        *MOUSE_XS = sub(){ $value };
+    }
 
     # definition of mro::get_linear_isa()
     my $get_linear_isa;
@@ -411,7 +414,7 @@ Mouse::Util - Utilities for working with Mouse classes
 
 =head1 VERSION
 
-This document describes Mouse version 2.4.1
+This document describes Mouse version 2.4.2
 
 =head1 SYNOPSIS
 
